@@ -29,19 +29,16 @@ app.directive('bmPeWatch', function() {
   };
 });
 
-//Executes the specified expression as a watcher
-//Adds a simple wrapper method to allow use of $watch instead of $watchCollection
-app.directive('bmPeWatchLiteral', function($parse) {
-  function retZero() {
-    return 0;
-  }
-
+//Executes the specified expression as a collection watcher
+app.directive('bmPeWatchCollection', function() {
   return {
     restrict: 'A',
     compile: function($element, $attrs) {
-      $element.text($attrs.bmPeWatchLiteral);
+      $element.text($attrs.bmPeWatchCollection);
       return function($scope, $element, $attrs) {
-        $scope.$watch($parse($attrs.bmPeWatchLiteral, retZero));
+        $scope.$watchCollection($attrs.bmPeWatchCollection, function(val) {
+          $element.text(val);
+        });
       };
     }
   };
@@ -72,8 +69,7 @@ app.controller('DataController', function($scope, $rootScope) {
       date2: new Date(Math.random() * Date.now()),
       func: function() { return star; },
       obj: data[i - 1],
-      keys: data[i - 1] && (data[i - 1].keys || Object.keys(data[i - 1])),
-      constructor: data[i - 1]
+      keys: data[i - 1] && (data[i - 1].keys || Object.keys(data[i - 1]))
     });
   }
 
