@@ -1,4 +1,4 @@
-"use strict";
+'use strict';
 var StringMap = require('stringmap');
 
 /**
@@ -7,4 +7,4 @@ var StringMap = require('stringmap');
  */
 module.exports = function errorNamespaceMap() {
   return new StringMap();
-};
\ No newline at end of file
+};
