@@ -58,27 +58,27 @@ $provide.value("$locale", {
       "decembro"
     ],
     "SHORTDAY": [
-      "dom",
-      "lun",
-      "mar",
-      "m\u00e9r",
-      "xov",
-      "ven",
-      "s\u00e1b"
+      "dom.",
+      "luns",
+      "mar.",
+      "m\u00e9r.",
+      "xov.",
+      "ven.",
+      "s\u00e1b."
     ],
     "SHORTMONTH": [
-      "xan",
-      "feb",
-      "mar",
-      "abr",
-      "mai",
-      "xu\u00f1",
-      "xul",
-      "ago",
-      "set",
-      "out",
-      "nov",
-      "dec"
+      "xan.",
+      "feb.",
+      "mar.",
+      "abr.",
+      "maio",
+      "xu\u00f1o",
+      "xul.",
+      "ago.",
+      "set.",
+      "out.",
+      "nov.",
+      "dec."
     ],
     "STANDALONEMONTH": [
       "Xaneiro",
@@ -98,10 +98,10 @@ $provide.value("$locale", {
       5,
       6
     ],
-    "fullDate": "EEEE dd MMMM y",
-    "longDate": "dd MMMM y",
-    "medium": "d MMM, y HH:mm:ss",
-    "mediumDate": "d MMM, y",
+    "fullDate": "EEEE, d 'de' MMMM 'de' y",
+    "longDate": "d 'de' MMMM 'de' y",
+    "medium": "d 'de' MMM 'de' y HH:mm:ss",
+    "mediumDate": "d 'de' MMM 'de' y",
     "mediumTime": "HH:mm:ss",
     "short": "dd/MM/yy HH:mm",
     "shortDate": "dd/MM/yy",
@@ -129,10 +129,10 @@ $provide.value("$locale", {
         "maxFrac": 2,
         "minFrac": 2,
         "minInt": 1,
-        "negPre": "-\u00a4",
-        "negSuf": "",
-        "posPre": "\u00a4",
-        "posSuf": ""
+        "negPre": "-",
+        "negSuf": "\u00a0\u00a4",
+        "posPre": "",
+        "posSuf": "\u00a0\u00a4"
       }
     ]
   },
