@@ -50,7 +50,7 @@ $provide.value("$locale", {
       "sa\u014b c\u00ff\u00f3",
       "sa\u014b ts\u025b\u0300\u025b c\u00ff\u00f3",
       "sa\u014b nj\u00ffol\u00e1\u02bc",
-      "sa\u014b ty\u025b\u0300b ty\u025b\u0300b mb\u0289\u0300",
+      "sa\u014b ty\u025b\u0300b ty\u025b\u0300b mb\u0289\u0300\u014b",
       "sa\u014b mb\u0289\u0300\u014b",
       "sa\u014b ngw\u0254\u0300\u02bc mb\u00ff\u025b",
       "sa\u014b t\u00e0\u014ba tsets\u00e1\u02bc",
@@ -73,7 +73,7 @@ $provide.value("$locale", {
       "sa\u014b c\u00ff\u00f3",
       "sa\u014b ts\u025b\u0300\u025b c\u00ff\u00f3",
       "sa\u014b nj\u00ffol\u00e1\u02bc",
-      "sa\u014b ty\u025b\u0300b ty\u025b\u0300b mb\u0289\u0300",
+      "sa\u014b ty\u025b\u0300b ty\u025b\u0300b mb\u0289\u0300\u014b",
       "sa\u014b mb\u0289\u0300\u014b",
       "sa\u014b ngw\u0254\u0300\u02bc mb\u00ff\u025b",
       "sa\u014b t\u00e0\u014ba tsets\u00e1\u02bc",
@@ -87,7 +87,7 @@ $provide.value("$locale", {
       "sa\u014b c\u00ff\u00f3",
       "sa\u014b ts\u025b\u0300\u025b c\u00ff\u00f3",
       "sa\u014b nj\u00ffol\u00e1\u02bc",
-      "sa\u014b ty\u025b\u0300b ty\u025b\u0300b mb\u0289\u0300",
+      "sa\u014b ty\u025b\u0300b ty\u025b\u0300b mb\u0289\u0300\u014b",
       "sa\u014b mb\u0289\u0300\u014b",
       "sa\u014b ngw\u0254\u0300\u02bc mb\u00ff\u025b",
       "sa\u014b t\u00e0\u014ba tsets\u00e1\u02bc",
