@@ -4,17 +4,17 @@ var PLURAL_CATEGORY = {ZERO: "zero", ONE: "one", TWO: "two", FEW: "few", MANY: "
 $provide.value("$locale", {
   "DATETIME_FORMATS": {
     "AMPMS": [
-      "Ekuseni",
-      "Ntambama"
+      "AM",
+      "PM"
     ],
     "DAY": [
-      "Sonto",
-      "Msombuluko",
-      "Lwesibili",
-      "Lwesithathu",
-      "Lwesine",
-      "Lwesihlanu",
-      "Mgqibelo"
+      "ISonto",
+      "UMsombuluko",
+      "ULwesibili",
+      "ULwesithathu",
+      "ULwesine",
+      "ULwesihlanu",
+      "UMgqibelo"
     ],
     "ERANAMES": [
       "BC",
@@ -26,10 +26,10 @@ $provide.value("$locale", {
     ],
     "FIRSTDAYOFWEEK": 6,
     "MONTH": [
-      "Januwari",
+      "UMasingana",
       "Februwari",
       "Mashi",
-      "Apreli",
+      "Ephreli",
       "Meyi",
       "Juni",
       "Julayi",
@@ -52,7 +52,7 @@ $provide.value("$locale", {
       "Jan",
       "Feb",
       "Mas",
-      "Apr",
+      "Eph",
       "Mey",
       "Jun",
       "Jul",
@@ -66,7 +66,7 @@ $provide.value("$locale", {
       "Januwari",
       "Februwari",
       "Mashi",
-      "Apreli",
+      "Ephreli",
       "Meyi",
       "Juni",
       "Julayi",
@@ -82,12 +82,12 @@ $provide.value("$locale", {
     ],
     "fullDate": "EEEE, MMMM d, y",
     "longDate": "MMMM d, y",
-    "medium": "MMM d, y h:mm:ss a",
+    "medium": "MMM d, y HH:mm:ss",
     "mediumDate": "MMM d, y",
-    "mediumTime": "h:mm:ss a",
-    "short": "M/d/yy h:mm a",
+    "mediumTime": "HH:mm:ss",
+    "short": "M/d/yy HH:mm",
     "shortDate": "M/d/yy",
-    "shortTime": "h:mm a"
+    "shortTime": "HH:mm"
   },
   "NUMBER_FORMATS": {
     "CURRENCY_SYM": "R",
