@@ -152,7 +152,7 @@ describe('$$AnimateRunner', function() {
 
     var runner = new $$AnimateRunner();
     var animationFailed = false;
-    runner['catch'](function() {
+    runner.catch(function() {
       animationFailed = true;
     });
     runner.cancel();
@@ -161,14 +161,13 @@ describe('$$AnimateRunner', function() {
   }));
 
   it('should use timeouts to trigger async operations when the document is hidden', function() {
-    var doc;
+    var hidden = true;
 
     module(function($provide) {
-      doc = jqLite({
-        body: window.document.body,
-        hidden: true
+
+      $provide.value('$$isDocumentHidden', function() {
+        return hidden;
       });
-      $provide.value('$document', doc);
     });
 
     inject(function($$AnimateRunner, $rootScope, $$rAF, $timeout) {
@@ -182,7 +181,7 @@ describe('$$AnimateRunner', function() {
       $timeout.flush();
       expect(spy).toHaveBeenCalled();
 
-      doc[0].hidden = false;
+      hidden = false;
 
       spy = jasmine.createSpy();
       runner = new $$AnimateRunner();
@@ -202,9 +201,9 @@ describe('$$AnimateRunner', function() {
     inject(function($$AnimateRunner, $rootScope) {
         var runner = new $$AnimateRunner();
         var animationComplete = false;
-        runner['finally'](function() {
+        runner.finally(function() {
           animationComplete = true;
-        });
+        }).catch(noop);
         runner[method]();
         $rootScope.$digest();
         expect(animationComplete).toBe(true);
@@ -330,7 +329,7 @@ describe('$$AnimateRunner', function() {
       expect(status).toBe(true);
     }));
 
-    it('should break the chian when a function evaluates to false',
+    it('should break the chain when a function evaluates to false',
       inject(function($$rAF, $$AnimateRunner) {
 
       var runner1 = new $$AnimateRunner();
