@@ -1,6 +1,6 @@
 'use strict';
 
-describe("ngAnimate $$animateCssDriver", function() {
+describe('ngAnimate $$animateCssDriver', function() {
 
   beforeEach(module('ngAnimate'));
   beforeEach(module('ngAnimateMock'));
@@ -89,18 +89,18 @@ describe("ngAnimate $$animateCssDriver", function() {
       expect($animateProvider.drivers).toContain('$$animateCssDriver');
     }));
 
-    describe("regular animations", function() {
-      it("should render an animation on the given element", inject(function() {
+    describe('regular animations', function() {
+      it('should render an animation on the given element', inject(function() {
         driver({ element: element });
         expect(capturedAnimation[0]).toBe(element);
       }));
 
-      it("should return an object with a start function", inject(function() {
+      it('should return an object with a start function', inject(function() {
         var runner = driver({ element: element });
         expect(isFunction(runner.start)).toBeTruthy();
       }));
 
-      it("should not signal $animateCss to apply the classes early when animation is structural", inject(function() {
+      it('should not signal $animateCss to apply the classes early when animation is structural', inject(function() {
         driver({ element: element });
         expect(capturedAnimation[1].applyClassesEarly).toBeFalsy();
 
@@ -108,7 +108,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(capturedAnimation[1].applyClassesEarly).toBeTruthy();
       }));
 
-      it("should only set the event value if the animation is structural", inject(function() {
+      it('should only set the event value if the animation is structural', inject(function() {
         driver({ element: element, structural: true, event: 'superman' });
         expect(capturedAnimation[1].event).toBe('superman');
 
@@ -117,7 +117,7 @@ describe("ngAnimate $$animateCssDriver", function() {
       }));
     });
 
-    describe("anchored animations", function() {
+    describe('anchored animations', function() {
       var from, to, fromAnimation, toAnimation;
 
       beforeEach(module(function() {
@@ -140,7 +140,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         };
       }));
 
-      it("should not return anything if no animation is detected", function() {
+      it('should not return anything if no animation is detected', function() {
         module(function($provide) {
           $provide.value('$animateCss', function() {
             return { $$willAnimate: false };
@@ -155,7 +155,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         });
       });
 
-      it("should return a start method", inject(function() {
+      it('should return a start method', inject(function() {
         var animator = driver({
           from: fromAnimation,
           to: toAnimation
@@ -163,7 +163,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(isFunction(animator.start)).toBeTruthy();
       }));
 
-      they("should return a runner with a $prop() method which will end the animation",
+      they('should return a runner with a $prop() method which will end the animation',
         ['end', 'cancel'], function(method) {
 
         var closeAnimation;
@@ -203,7 +203,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         });
       });
 
-      it("should end the animation for each of the from and to elements as well as all the anchors", function() {
+      it('should end the animation for each of the from and to elements as well as all the anchors', function() {
         var closeLog = {};
         module(function($provide) {
           $provide.factory('$animateCss', function($q, $$AnimateRunner) {
@@ -255,7 +255,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         });
       });
 
-      it("should render an animation on both the from and to elements", inject(function() {
+      it('should render an animation on both the from and to elements', inject(function() {
         captureFn = function(element, details) {
           element.addClass(details.event);
         };
@@ -273,7 +273,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(toAnimation.element).toHaveClass('leave');
       }));
 
-      it("should start the animations on the from and to elements in parallel", function() {
+      it('should start the animations on the from and to elements in parallel', function() {
         var animationLog = [];
         module(function($provide) {
           $provide.factory('$animateCss', function($$AnimateRunner) {
@@ -306,7 +306,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         });
       });
 
-      it("should start an animation for each anchor", inject(function() {
+      it('should start an animation for each anchor', inject(function() {
         var o1 = jqLite('<div></div>');
         from.append(o1);
         var o2 = jqLite('<div></div>');
@@ -336,7 +336,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(captureLog.length).toBe(5);
       }));
 
-      it("should create a clone of the starting element for each anchor animation", inject(function() {
+      it('should create a clone of the starting element for each anchor animation', inject(function() {
         var o1 = jqLite('<div class="out1"></div>');
         from.append(o1);
         var o2 = jqLite('<div class="out2"></div>');
@@ -367,7 +367,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(a2.attr('class')).toMatch(/\bout2\b/);
       }));
 
-      it("should create a clone of the starting element and place it at the end of the $rootElement container",
+      it('should create a clone of the starting element and place it at the end of the $rootElement container',
         inject(function($rootElement) {
 
         //stick some garbage into the rootElement
@@ -397,7 +397,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(contents[contents.length - 1]).toEqual(anchorNode);
       }));
 
-      it("should first do an addClass('ng-anchor-out') animation on the cloned anchor", inject(function($rootElement) {
+      it('should first do an addClass(\'ng-anchor-out\') animation on the cloned anchor', inject(function($rootElement) {
         var fromAnchor = jqLite('<div></div>');
         from.append(fromAnchor);
         var toAnchor = jqLite('<div></div>');
@@ -420,7 +420,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(anchorDetails.event).toBeFalsy();
       }));
 
-      it("should then do an addClass('ng-anchor-in') animation on the cloned anchor and remove the old class",
+      it('should then do an addClass(\'ng-anchor-in\') animation on the cloned anchor and remove the old class',
         inject(function($rootElement) {
 
         var fromAnchor = jqLite('<div></div>');
@@ -448,7 +448,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(anchorDetails.event).toBeFalsy();
       }));
 
-      they("should only fire the ng-anchor-$prop animation if only a $prop animation is defined",
+      they('should only fire the ng-anchor-$prop animation if only a $prop animation is defined',
         ['out', 'in'], function(direction) {
 
         var expectedClass = 'ng-anchor-' + direction;
@@ -463,7 +463,8 @@ describe("ngAnimate $$animateCssDriver", function() {
                 $$willAnimate: addClass === expectedClass,
                 start: function() {
                   animationStarted = addClass;
-                  return runner = new $$AnimateRunner();
+                  runner = new $$AnimateRunner();
+                  return runner;
                 }
               };
             };
@@ -500,7 +501,7 @@ describe("ngAnimate $$animateCssDriver", function() {
       });
 
 
-      it("should provide an explicit delay setting in the options provided to $animateCss for anchor animations",
+      it('should provide an explicit delay setting in the options provided to $animateCss for anchor animations',
         inject(function($rootElement) {
 
         var fromAnchor = jqLite('<div></div>');
@@ -523,7 +524,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(capturedAnimation[1].delay).toBeTruthy();
       }));
 
-      it("should begin the anchor animation by seeding the from styles based on where the from anchor element is positioned",
+      it('should begin the anchor animation by seeding the from styles based on where the from anchor element is positioned',
         inject(function($rootElement) {
 
         ss.addRule('.starting-element', 'width:200px; height:100px; display:block;');
@@ -558,7 +559,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(int(fromStyles.left)).toBeGreaterThan(149);
       }));
 
-      it("should append a `px` value for all seeded animation styles", inject(function($rootElement) {
+      it('should append a `px` value for all seeded animation styles', inject(function($rootElement) {
         ss.addRule('.starting-element', 'width:10px; height:20px; display:inline-block;');
 
         var fromAnchor = jqLite('<div class="starting-element"' +
@@ -597,7 +598,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         });
       }));
 
-      it("should then do an removeClass('out') + addClass('in') animation on the cloned anchor",
+      it('should then do an removeClass(\'out\') + addClass(\'in\') animation on the cloned anchor',
         inject(function($rootElement) {
 
         var fromAnchor = jqLite('<div></div>');
@@ -626,7 +627,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(anchorDetails.event).toBeFalsy();
       }));
 
-      it("should add the `ng-anchor` class to the cloned anchor element",
+      it('should add the `ng-anchor` class to the cloned anchor element',
         inject(function($rootElement) {
 
         var fromAnchor = jqLite('<div></div>');
@@ -650,7 +651,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(clonedAnchor).toHaveClass('ng-anchor');
       }));
 
-      it("should add and remove the `ng-animate-shim` class on the in anchor element during the animation",
+      it('should add and remove the `ng-animate-shim` class on the in anchor element during the animation',
         inject(function($rootElement) {
 
         var fromAnchor = jqLite('<div></div>');
@@ -679,7 +680,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(fromAnchor).not.toHaveClass('ng-animate-shim');
       }));
 
-      it("should add and remove the `ng-animate-shim` class on the out anchor element during the animation",
+      it('should add and remove the `ng-animate-shim` class on the out anchor element during the animation',
         inject(function($rootElement) {
 
         var fromAnchor = jqLite('<div></div>');
@@ -710,7 +711,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(toAnchor).not.toHaveClass('ng-animate-shim');
       }));
 
-      it("should create the cloned anchor with all of the classes from the from anchor element",
+      it('should create the cloned anchor with all of the classes from the from anchor element',
         inject(function($rootElement) {
 
         var fromAnchor = jqLite('<div class="yes no maybe"></div>');
@@ -734,7 +735,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(hasAll(addedClasses, ['yes', 'no', 'maybe'])).toBe(true);
       }));
 
-      it("should remove the classes of the starting anchor from the cloned anchor node during the in animation and also add the classes of the destination anchor within the same animation",
+      it('should remove the classes of the starting anchor from the cloned anchor node during the in animation and also add the classes of the destination anchor within the same animation',
         inject(function($rootElement) {
 
         var fromAnchor = jqLite('<div class="yes no maybe"></div>');
@@ -765,7 +766,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(hasAll(addedClasses, ['why', 'ok', 'so-what'])).toBe(true);
       }));
 
-      it("should not attempt to add/remove any classes that contain a `ng-` prefix",
+      it('should not attempt to add/remove any classes that contain a `ng-` prefix',
         inject(function($rootElement) {
 
         var fromAnchor = jqLite('<div class="ng-yes ng-no sure"></div>');
@@ -801,7 +802,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(removedClasses).not.toContain('ng-no');
       }));
 
-      it("should not remove any shared CSS classes between the starting and destination anchor element during the in animation",
+      it('should not remove any shared CSS classes between the starting and destination anchor element during the in animation',
         inject(function($rootElement) {
 
         var fromAnchor = jqLite('<div class="blue green red"></div>');
@@ -849,7 +850,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(clonedAnchor).toHaveClass('blue');
       }));
 
-      it("should continue the anchor animation by seeding the to styles based on where the final anchor element will be positioned",
+      it('should continue the anchor animation by seeding the to styles based on where the final anchor element will be positioned',
       inject(function($rootElement) {
         ss.addRule('.ending-element', 'width:9999px; height:6666px; display:inline-block;');
 
@@ -886,7 +887,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(int(toStyles.left)).toBeGreaterThan(20);
       }));
 
-      it("should remove the cloned anchor node from the DOM once the 'in' animation is complete",
+      it('should remove the cloned anchor node from the DOM once the \'in\' animation is complete',
         inject(function($rootElement) {
 
         var fromAnchor = jqLite('<div class="blue green red"></div>');
@@ -919,7 +920,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(clonedAnchor.parent().length).toBe(0);
       }));
 
-      it("should pass the provided domOperation into $animateCss to be run right after the element is animated if a leave animation is present",
+      it('should pass the provided domOperation into $animateCss to be run right after the element is animated if a leave animation is present',
         inject(function($rootElement) {
 
         toAnimation.structural = true;
@@ -945,7 +946,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(enterAnimation.args[1].onDone).toBeUndefined();
       }));
 
-      it("should fire the returned runner promise when the from, to and anchor animations are all complete",
+      it('should fire the returned runner promise when the from, to and anchor animations are all complete',
         inject(function($rootElement, $rootScope, $animate) {
 
         ss.addRule('.ending-element', 'width:9999px; height:6666px; display:inline-block;');
@@ -982,7 +983,7 @@ describe("ngAnimate $$animateCssDriver", function() {
         expect(completed).toBe(true);
       }));
 
-      it("should use <body> as the element container if the rootElement exists outside of the <body> tag", function() {
+      it('should use <body> as the element container if the rootElement exists outside of the <body> tag', function() {
         module(function($provide) {
           $provide.factory('$rootElement', function($document) {
             return jqLite($document[0].querySelector('html'));
